/*
 * Copyright 2007-2020 Charles du Jeu - Abstrium SAS <team (at) pyd.io>
 * This file is part of Pydio.
 *
 * Pydio is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Pydio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Pydio.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The latest code can be found at <https://pydio.com>.
 */
'use strict';

exports.__esModule = true;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _pydio = require('pydio');

var _pydio2 = _interopRequireDefault(_pydio);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _materialUi = require('material-ui');

var _toggleBmNode = require("./toggleBmNode");

var _toggleBmNode2 = _interopRequireDefault(_toggleBmNode);

var BookmarkButton = (function (_React$Component) {
    _inherits(BookmarkButton, _React$Component);

    function BookmarkButton(props) {
        _classCallCheck(this, BookmarkButton);

        _React$Component.call(this, props);
        this.state = this.valueFromNodes(props.nodes);
    }

    BookmarkButton.prototype.valueFromNodes = function valueFromNodes() {
        var nodes = arguments.length <= 0 || arguments[0] === undefined ? [] : arguments[0];

        var mixed = undefined,
            value = undefined;
        nodes.forEach(function (n) {
            var nVal = n.getMetadata().get('bookmark') === 'true';
            if (value !== undefined && nVal !== value) {
                mixed = true;
            }
            value = nVal;
        });
        return { value: value, mixed: mixed };
    };

    BookmarkButton.prototype.updateValue = function updateValue(value) {
        var _this = this;

        var nodes = this.props.nodes;

        this.setState({ saving: true });
        var proms = [];
        nodes.forEach(function (n) {
            var isBookmarked = n.getMetadata().get('bookmark') === 'true';
            if (value !== isBookmarked) {
                proms.push(_toggleBmNode2['default'](n));
                var overlay = n.getMetadata().get('overlay_class') || '';
                if (value) {
                    n.getMetadata().set('bookmark', 'true');
                    var overlays = overlay.replace('mdi mdi-star', '').split(',');
                    overlays.push('mdi mdi-star');
                    n.getMetadata().set('overlay_class', overlays.join(','));
                } else {
                    n.getMetadata()['delete']('bookmark');
                    n.getMetadata().set('overlay_class', overlay.replace('mdi mdi-star', ''));
                }
                n.notify('node_replaced');
            }
        });
        Promise.all(proms).then(function () {
            window.setTimeout(function () {
                _this.setState({ saving: false });
            }, 250);
            _this.setState(_this.valueFromNodes(nodes));
        })['catch'](function () {
            _this.setState({ saving: false });
        });
    };

    BookmarkButton.prototype.render = function render() {
        var _this2 = this;

        var styles = this.props.styles;
        var _state = this.state;
        var value = _state.value;
        var mixed = _state.mixed;
        var saving = _state.saving;

        var icon = undefined,
            touchValue = undefined,
            tt = undefined,
            disabled = undefined;
        var mm = _pydio2['default'].getInstance().MessageHash;
        if (mixed) {
            icon = 'star-half';
            touchValue = true;
            tt = mm['bookmark.button.tip.mixed'];
        } else if (value) {
            icon = 'star';
            touchValue = false;
            tt = mm['bookmark.button.tip.remove'];
        } else {
            icon = 'star-outline';
            touchValue = true;
            tt = mm['bookmark.button.tip.add'];
        }

        if (saving) {
            icon = 'star-circle';
            tt = mm['bookmark.button.tip.saving'];
            disabled = true;
        }

        return _react2['default'].createElement(_materialUi.IconButton, _extends({ disabled: disabled, iconClassName: 'mdi mdi-' + icon, tooltip: tt, onTouchTap: function () {
                return _this2.updateValue(touchValue);
            } }, styles));
    };

    return BookmarkButton;
})(_react2['default'].Component);

exports['default'] = BookmarkButton;
module.exports = exports['default'];
